from distutils.core import setup
setup (
        name = 'nester_learn_1',
        version = '1.0.0',
        py_modules = ['nester_learn_1'],
        author = 'hfpython',
        author_email = '2683731045@qq.com',
        url = 'http://www.qq.com',
        description = 'A simple printer of nested lists',
        )
